@@ -40,7 +40,7 @@ launch <- function(package = "radiant.data", run = "viewer", state, ...) {
     message(sprintf("\nStarting %s at the url shown below ...\nClick on the link or copy-and-paste it into\nyour browser's url bar to start", package))
     options(radiant.launch = "browser")
   } else if (run == "browser" || run == "external") {
-    message(sprintf("\nStarting %s in the default browser ...\n\nUse %s::%s_viewer() in Rstudio to open %s in the Rstudio viewer\nor %s::%s_window() in Rstudio to open %s in an Rstudio window", package, package, package, package, package, package, package))
+    message(sprintf("\nStarting %s in the default browser", package))
     options(radiant.launch = "browser")
     run <- TRUE
   } else if (rstudioapi::getVersion() < "1.1") {
@@ -58,11 +58,13 @@ launch <- function(package = "radiant.data", run = "viewer", state, ...) {
     options(radiant.launch = "window")
     run <- get(".rs.invokeShinyWindowViewer")
   } else {
-    message(sprintf("\nStarting %s in the default browser ...\n\nUse %s::%s_viewer() in Rstudio to open %s in the Rstudio viewer or %s::%s_window() in Rstudio to open %s in an Rstudio window", package, package, package, package, package, package, package))
+    message(sprintf("\nStarting %s in the default browser", package))
     options(radiant.launch = "browser")
     run <- TRUE
   }
 
+  cat("\nRadiant is opensource and free to use. If you are a student or instructor using Radiant for a class, as a favor to the developer, please send an email to <radiant@rady.ucsd.edu> with the name of the school and class\n")
+
   ## load radiant state file if specified
   if (!missing(state)) {
     if (grepl("^www\\.|^http:|^https:", state)) {
@@ -72,7 +74,7 @@ launch <- function(package = "radiant.data", run = "viewer", state, ...) {
     }
   }
 
-  ## cannot (yet) supress ERROR: [on_request_read] connection reset by peer in viewer
+  ## cannot (yet) suppress ERROR: [on_request_read] connection reset by peer in viewer
   suppressPackageStartupMessages(
     shiny::runApp(system.file("app", package = package), launch.browser = run, ...)
   )
@@ -192,7 +194,7 @@ sig_stars <- function(pval) {
 
 #' Hide warnings and messages and return invisible
 #'
-#' @details Adapted from \url{https://www.onthelambda.com/2014/09/17/fun-with-rprofile-and-customizing-r-startup/}
+#' @details Hide warnings and messages and return invisible
 #'
 #' @param ... Inputs to keep quite
 #'
@@ -206,7 +208,7 @@ sshh <- function(...) {
 
 #' Hide warnings and messages and return result
 #'
-#' @details Adapted from \url{https://www.onthelambda.com/2014/09/17/fun-with-rprofile-and-customizing-r-startup/}
+#' @details Hide warnings and messages and return result
 #'
 #' @param ... Inputs to keep quite
 #'
