@@ -12,17 +12,25 @@ viz_theme <- c(
   "Light" = "theme_light", "Dark" = "theme_dark",
   "Minimal" = "theme_minimal", "Classic" = "theme_classic"
 )
-viz_base_family = c(
-  "Theme default" = "", "Helvetica" = "Helvetica", "Serif" = "serif",
-  "Sans" = "sans", "Mono" = "mono", "Courier" = "Courier", "Times" = "Times"
-)
+
+os_type <- Sys.info()["sysname"]
+if (os_type == "Windows") {
+  fnt <- names(windowsFonts())
+  names(fnt) <- tools::toTitleCase(fnt)
+  viz_base_family <- c("Theme default" = "", fnt)
+} else {
+  viz_base_family <- c(
+    "Theme default" = "", "Helvetica" = "Helvetica", "Serif" = "serif",
+    "Sans" = "sans", "Mono" = "mono", "Courier" = "Courier", "Times" = "Times"
+  )
+}
 
 viz_labs <- c("title", "subtitle", "caption", "x", "y")
 viz_add_labs <- function() {
   lab_list <- list()
-  for(l in viz_labs) {
+  for (l in viz_labs) {
     inp <- input[[paste0("viz_labs_", l)]]
-    if(!is_empty(inp)) lab_list[[l]] <- inp
+    if (!radiant.data::is_empty(inp)) lab_list[[l]] <- inp
   }
   lab_list
 }
@@ -37,8 +45,9 @@ viz_inputs <- reactive({
   viz_args$dataset <- input$dataset
   viz_args$shiny <- input$shiny
   viz_args$labs <- viz_add_labs()
-  for (i in r_drop(names(viz_args), drop = c("dataset", "data_filter", "labs")))
+  for (i in r_drop(names(viz_args), drop = c("dataset", "data_filter", "labs"))) {
     viz_args[[i]] <- input[[paste0("viz_", i)]]
+  }
   # isolate({
   #   # cat(paste0(names(viz_args), " ", viz_args, collapse = ", "), file = stderr(), "\n")
   #   cat(paste0(names(viz_args), " = ", viz_args, collapse = ", "), "\n")
@@ -171,7 +180,8 @@ output$ui_viz_color <- renderUI({
 
   if (isTRUE(input$viz_comby) && length(input$viz_yvar) > 1) vars <- c("None" = "none")
   selectizeInput(
-    "viz_color", "Color:", vars, multiple = FALSE,
+    "viz_color", "Color:", vars,
+    multiple = FALSE,
     selected = state_single("viz_color", vars, init = "none")
   )
 })
@@ -180,7 +190,8 @@ output$ui_viz_fill <- renderUI({
   vars <- c("None" = "none", groupable_vars())
   if (isTRUE(input$viz_combx) && length(input$viz_xvar) > 1) vars <- vars[1]
   selectizeInput(
-    "viz_fill", "Fill:", vars, multiple = FALSE,
+    "viz_fill", "Fill:", vars,
+    multiple = FALSE,
     selected = state_single("viz_fill", vars, init = "none")
   )
 })
@@ -191,7 +202,8 @@ output$ui_viz_size <- renderUI({
   vars <- c("None" = "none", varnames()[isNum])
   if (isTRUE(input$viz_comby) && length(input$viz_yvar) > 1) vars <- c("None" = "none")
   selectizeInput(
-    "viz_size", "Size:", vars, multiple = FALSE,
+    "viz_size", "Size:", vars,
+    multiple = FALSE,
     selected = state_single("viz_size", vars, init = "none")
   )
 })
@@ -208,8 +220,9 @@ output$ui_viz_axes <- renderUI({
   } else if (input$viz_type %in% c("bar", "box")) {
     ind <- c(1, 3)
   }
-  if (!is_empty(input$viz_facet_row, ".") || !is_empty(input$viz_facet_col, ".")) ind <- c(ind, 4)
-  if (input$viz_type == "bar" && input$viz_facet_row == "." && input$viz_facet_col == ".") ind <- c(ind, 6)
+  if (!radiant.data::is_empty(input$viz_facet_row, ".") || !radiant.data::is_empty(input$viz_facet_col, ".")) ind <- c(ind, 4)
+  # if (input$viz_type == "bar" && input$viz_facet_row == "." && input$viz_facet_col == ".") ind <- c(ind, 6)
+  if (input$viz_type == "bar") ind <- c(ind, 6)
 
   checkboxGroupInput(
     "viz_axes", NULL, viz_axes[ind],
@@ -273,7 +286,8 @@ output$ui_viz_colors <- renderUI({
                    input.viz_type == 'box' ||
                    input.viz_type == 'density'",
       selectInput(
-        "viz_fillcol", "Fill color:", choices = colors(),
+        "viz_fillcol", "Fill color:",
+        choices = colors(),
         selected = state_single("viz_fillcol", colors(), "blue")
       )
     ),
@@ -284,7 +298,8 @@ output$ui_viz_colors <- renderUI({
                    input.viz_type == 'scatter' ||
                    input.viz_type == 'line'",
       selectInput(
-        "viz_linecol", "Line color:", choices = colors(),
+        "viz_linecol", "Line color:",
+        choices = colors(),
         selected = state_single("viz_linecol", colors(), "black")
       )
     ),
@@ -293,7 +308,8 @@ output$ui_viz_colors <- renderUI({
                    input.viz_type == 'line' ||
                    input.viz_type == 'box'",
       selectInput(
-        "viz_pointcol", "Point color:", choices = colors(),
+        "viz_pointcol", "Point color:",
+        choices = colors(),
         selected = state_single("viz_pointcol", colors(), "black")
       )
     )
@@ -302,7 +318,8 @@ output$ui_viz_colors <- renderUI({
 
 ## add a spinning refresh icon if the tabel needs to be (re)calculated
 run_refresh(
-  viz_args, "viz", init = "xvar", label = "Create plot", relabel = "Update plot",
+  viz_args, "viz",
+  init = "xvar", label = "Create plot", relabel = "Update plot",
   inputs = c("labs_title", "labs_subtitle", "labs_caption", "labs_y", "labs_x")
 )
 
@@ -312,10 +329,12 @@ output$ui_Visualize <- renderUI({
       uiOutput("ui_viz_run")
     ),
     checkboxInput("viz_details_main", "Main", state_init("viz_details_main", TRUE)),
-    conditionalPanel("input.viz_details_main == true",
+    conditionalPanel(
+      "input.viz_details_main == true",
       wellPanel(
         uiOutput("ui_viz_type"),
-        conditionalPanel("input.viz_type == 'scatter'",
+        conditionalPanel(
+          "input.viz_type == 'scatter'",
           uiOutput("ui_viz_nrobs")
         ),
         conditionalPanel(
@@ -358,7 +377,8 @@ output$ui_Visualize <- renderUI({
                        input.viz_type == 'scatter' ||
                        input.viz_type == 'line'",
           selectInput(
-            "viz_fun", "Function:", choices =  getOption("radiant.functions"),
+            "viz_fun", "Function:",
+            choices = getOption("radiant.functions"),
             selected = state_single("viz_fun", getOption("radiant.functions"), "mean")
           )
         ),
@@ -373,18 +393,19 @@ output$ui_Visualize <- renderUI({
         conditionalPanel(
           condition = "input.viz_type == 'dist'",
           sliderInput(
-            "viz_bins", label = "Number of bins:",
+            "viz_bins",
+            label = "Number of bins:",
             value = state_init("viz_bins", 10),
             min = 2, max = 50, step = 1
           )
         ),
-
         conditionalPanel(
           "input.viz_type == 'density' ||
            input.viz_type == 'dist' && (input.viz_axes && input.viz_axes.indexOf('density')) >= 0 ||
            (input.viz_type == 'scatter' && (input.viz_check && input.viz_check.indexOf('loess') >= 0))",
           sliderInput(
-            "viz_smooth", label = "Smooth:",
+            "viz_smooth",
+            label = "Smooth:",
             value = state_init("viz_smooth", 1),
             min = 0.1, max = 3, step = .1
           )
@@ -392,42 +413,55 @@ output$ui_Visualize <- renderUI({
       )
     ),
     checkboxInput("viz_details_labels", "Labels", state_init("viz_details_labels", FALSE)),
-    conditionalPanel("input.viz_details_labels == true",
+    conditionalPanel(
+      "input.viz_details_labels == true",
       uiOutput("ui_viz_labs")
     ),
     checkboxInput("viz_details_style", "Style", state_init("viz_details_style", FALSE)),
-    conditionalPanel("input.viz_details_style == true",
+    conditionalPanel(
+      "input.viz_details_style == true",
       wellPanel(
         selectInput(
-          "viz_theme", "Plot theme:", choices = viz_theme,
+          "viz_theme", "Plot theme:",
+          choices = viz_theme,
           selected = state_single("viz_theme", viz_theme, "theme_gray")
         ),
         numericInput(
-          "viz_base_size", "Base font size:", value = state_init("viz_base_size", 11)
+          "viz_base_size", "Base font size:",
+          value = state_init("viz_base_size", 11)
         ),
         selectInput(
-          "viz_base_family", "Font family:", choices = viz_base_family,
+          "viz_base_family", "Font family:",
+          choices = viz_base_family,
           selected = state_single("viz_base_family", viz_base_family, "helvetica")
         ),
         uiOutput("ui_viz_colors"),
         sliderInput(
-          "viz_alpha", label = "Opacity:",
+          "viz_alpha",
+          label = "Opacity:",
           value = state_init("viz_alpha", .5),
           min = 0, max = 1, step = .01
         ),
         tags$table(
-          tags$td(numericInput(
-            "viz_plot_height", label = "Plot height:", min = 100,
-            max = 2000, step = 50,
-            value = state_init("viz_plot_height", r_info[["plot_height"]]),
-            width = "117px"
-          )),
-          tags$td(numericInput(
-            "viz_plot_width", label = "Plot width:", min = 100,
-            max = 2000, step = 50,
-            value = state_init("viz_plot_width", r_info[["plot_width"]]),
-            width = "117px"
-          ))
+          tags$td(
+            numericInput(
+              "viz_plot_height",
+              label = "Plot height:", min = 100,
+              max = 2000, step = 50,
+              value = state_init("viz_plot_height", r_info[["plot_height"]]),
+              width = "117px"
+            )
+          ),
+          tags$td(
+            numericInput(
+              "viz_plot_width",
+              label = "Plot width:", min = 100,
+              max = 2000, step = 50,
+              value = state_init("viz_plot_width", r_info[["plot_width"]]),
+              width = "117px"
+            ),
+            width = "100%"
+          )
         )
       )
     ),
@@ -442,72 +476,93 @@ output$ui_Visualize <- renderUI({
 })
 
 viz_plot_width <- reactive({
-  if (is_empty(input$viz_plot_width)) r_info[["plot_width"]] else input$viz_plot_width
+  if (radiant.data::is_empty(input$viz_plot_width)) r_info[["plot_width"]] else input$viz_plot_width
 })
 
 ## based on https://stackoverflow.com/a/40182833/1974918
-viz_plot_height <- eventReactive({
-  input$viz_run
-  input$viz_plot_height
-  input$viz_plot_width
-}, {
-  if (is_empty(input$viz_plot_height)) {
-    r_info[["plot_height"]]
-  } else {
-    lx <- ifelse(not_available(input$viz_xvar) || isTRUE(input$viz_combx), 1, length(input$viz_xvar))
-    ly <- ifelse(not_available(input$viz_yvar) || input$viz_type %in% c("dist", "density") ||
-      isTRUE(input$viz_comby), 1, length(input$viz_yvar))
-    nr <- lx * ly
-    if (nr > 1) {
-      (input$viz_plot_height / 2) * ceiling(nr / 2)
+viz_plot_height <- eventReactive(
+  {
+    input$viz_run
+    input$viz_plot_height
+    input$viz_plot_width
+  },
+  {
+    if (radiant.data::is_empty(input$viz_plot_height)) {
+      r_info[["plot_height"]]
     } else {
-      input$viz_plot_height
+      lx <- ifelse(not_available(input$viz_xvar) || isTRUE(input$viz_combx), 1, length(input$viz_xvar))
+      ly <- ifelse(not_available(input$viz_yvar) || input$viz_type %in% c("dist", "density") ||
+        isTRUE(input$viz_comby), 1, length(input$viz_yvar))
+      nr <- lx * ly
+      if (nr > 1) {
+        (input$viz_plot_height / 2) * ceiling(nr / 2)
+      } else {
+        input$viz_plot_height
+      }
     }
   }
-})
+)
 
-output$visualize <- renderPlot({
-  if (not_available(input$viz_xvar)) {
-    return(
-      plot(
-        x = 1, type = "n",
-        main = "\nPlease select variables from the dropdown menus to create a plot",
-        axes = FALSE, xlab = "", ylab = "", cex.main = .9
-      )
-    )
-  }
-  .visualize() %>% {
-    if (is.character(.)) {
-      plot(x = 1, type = "n", main = paste0("\n", .), axes = FALSE, xlab = "", ylab = "", cex.main = .9)
-    } else if (is.null(.)) {
-      return(invisible())
-    } else {
-      print(.)
+output$visualize <- renderPlot(
+  {
+    req(input$viz_type)
+    if (not_available(input$viz_xvar)) {
+      if (input$viz_type != "box") {
+        return(
+          plot(
+            x = 1, type = "n",
+            main = "\nPlease select variables from the dropdown menus to create a plot",
+            axes = FALSE, xlab = "", ylab = "", cex.main = .9
+          )
+        )
+      }
     }
-  }
-}, width = viz_plot_width, height = viz_plot_height, res = 96)
+    .visualize() %>%
+      {
+        if (is.character(.)) {
+          plot(x = 1, type = "n", main = paste0("\n", .), axes = FALSE, xlab = "", ylab = "", cex.main = .9)
+        } else if (length(.) > 0) {
+          print(.)
+        }
+      }
+  },
+  width = viz_plot_width,
+  height = viz_plot_height,
+  res = 96
+)
 
 .visualize <- eventReactive(input$viz_run, {
-
   req(input$viz_type)
   if (input$viz_type == "scatter") req(input$viz_nrobs)
 
   ## need dependency on ..
   req(input$viz_plot_height && input$viz_plot_width)
 
-  if (not_available(input$viz_xvar)) return()
+  if (not_available(input$viz_xvar) && input$viz_type != "box") {
+    return()
+  }
   if (input$viz_type %in% c("scatter", "line", "box", "bar", "surface") && not_available(input$viz_yvar)) {
     return("No Y-variable provided for a plot that requires one")
   }
-  if (input$viz_type == "box" && !all(input$viz_xvar %in% groupable_vars())) return()
+  if (input$viz_type == "box" && !all(input$viz_xvar %in% groupable_vars())) {
+    return()
+  }
 
   ## waiting for comby and/or combx to be updated
   if (input$viz_type %in% c("dist", "density")) {
-    if (isTRUE(input$viz_comby)) return()
-    if (length(input$viz_xvar) > 1 && is.null(input$viz_combx)) return()
+    if (isTRUE(input$viz_comby)) {
+      return()
+    }
+    if (length(input$viz_xvar) > 1 && is.null(input$viz_combx)) {
+      return()
+    }
   } else {
-    if (isTRUE(input$viz_combx)) return()
-    if (length(input$viz_yvar) > 1 && is.null(input$viz_comby)) return()
+    if (isTRUE(input$viz_combx)) {
+      return()
+    }
+    if (length(input$viz_yvar) > 1 && is.null(input$viz_comby)) {
+      return()
+    }
   }
 
   req(!is.null(input$viz_color) || !is.null(input$viz_fill))
@@ -519,7 +574,7 @@ output$visualize <- renderPlot({
   })
 })
 
-observeEvent(input$visualize_report, {
+visualize_report <- function() {
   ## resetting hidden elements to default values
   vi <- viz_inputs()
   if (input$viz_type != "dist") {
@@ -529,7 +584,7 @@ observeEvent(input$visualize_report, {
     vi$yvar <- viz_args$yvar
   }
   if (!input$viz_type %in% c("density", "scatter", "dist") ||
-      !("loess" %in% input$viz_check || "density" %in% input$viz_axes || input$viz_type == "density")) {
+    !("loess" %in% input$viz_check || "density" %in% input$viz_axes || input$viz_type == "density")) {
     vi$smooth <- viz_args$smooth
   }
   if (!input$viz_type %in% c("scatter", "box") && "jitter" %in% input$viz_check) {
@@ -573,7 +628,7 @@ observeEvent(input$visualize_report, {
     fig.width = viz_plot_width(),
     fig.height = viz_plot_height()
   )
-})
+}
 
 download_handler(
   id = "dlp_visualize",
@@ -585,3 +640,18 @@ download_handler(
   width = viz_plot_width,
   height = viz_plot_height
 )
+
+observeEvent(input$visualize_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  visualize_report()
+})
+
+observeEvent(input$visualize_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_visualize_screenshot")
+})
+
+observeEvent(input$modal_visualize_screenshot, {
+  visualize_report()
+  removeModal()
+})
\ No newline at end of file
